@@ -5,12 +5,10 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at the  *
- * root level of an installed copy of the electronic HDF5 document set and   *
- * is linked from the top-level documents page.  It can also be found at     *
- * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /* Programmer:  Robb Matzke <matzke@llnl.gov>
@@ -97,11 +95,7 @@ typedef struct H5FD_stdio_t {
      * Windows code further below.
      */
     dev_t           device;     /* file device number   */
-#ifdef H5_VMS
-    ino_t           inode[3];   /* file i-node number   */
-#else
     ino_t           inode;      /* file i-node number   */
-#endif /* H5_VMS */
 #else
     /* Files in windows are uniquely identified by the volume serial
      * number and the file index (both low and high parts).
@@ -135,23 +129,14 @@ typedef struct H5FD_stdio_t {
 #endif /* H5_HAVE_MINGW */
 #endif /* H5_HAVE_WIN32_API */
 
-/* Use file_xxx to indicate these are local macros, avoiding confusing 
- * with the global HD_xxx macros. 
- * Assume fseeko, which is POSIX standard, is always supported; 
- * but prefer to use fseeko64 if supported. 
+/* If these functions weren't re-defined for Windows, give them
+ * more platform-independent names.
  */
 #ifndef file_fseek
-    #ifdef H5_HAVE_FSEEKO64
-        #define file_fseek      fseeko64
-        #define file_offset_t   off64_t
-        #define file_ftruncate  ftruncate64
-        #define file_ftell      ftello64
-    #else
-        #define file_fseek      fseeko
-        #define file_offset_t   off_t
-        #define file_ftruncate  ftruncate
-        #define file_ftell      ftello
-    #endif /* H5_HAVE_FSEEKO64 */
+    #define file_fseek      fseeko
+    #define file_offset_t   off_t
+    #define file_ftruncate  ftruncate
+    #define file_ftell      ftello
 #endif /* file_fseek */
 
 /* These macros check for overflow of various quantities.  These macros
@@ -363,26 +348,35 @@ H5FD_stdio_open( const char *name, unsigned flags, hid_t fapl_id,
     if (ADDR_OVERFLOW(maxaddr))
         H5Epush_ret(func, H5E_ERR_CLS, H5E_ARGS, H5E_OVERFLOW, "maxaddr too large", NULL)
 
-    /* Attempt to open/create the file */
-    if (access(name, F_OK) < 0) {
-        if ((flags & H5F_ACC_CREAT) && (flags & H5F_ACC_RDWR)) {
+    /* Tentatively open file in read-only mode, to check for existence */
+    if(flags & H5F_ACC_RDWR)
+        f = fopen(name, "rb+");
+    else
+        f = fopen(name, "rb");
+
+    if(!f) {
+        /* File doesn't exist */
+        if(flags & H5F_ACC_CREAT) {
+            assert(flags & H5F_ACC_RDWR);
             f = fopen(name, "wb+");
             write_access = 1;     /* Note the write access */
         }
         else
             H5Epush_ret(func, H5E_ERR_CLS, H5E_IO, H5E_CANTOPENFILE, "file doesn't exist and CREAT wasn't specified", NULL)
-    } else if ((flags & H5F_ACC_CREAT) && (flags & H5F_ACC_EXCL)) {
+    } else if(flags & H5F_ACC_EXCL) {
+        /* File exists, but EXCL is passed.  Fail. */
+        assert(flags & H5F_ACC_CREAT);
+        fclose(f);
         H5Epush_ret(func, H5E_ERR_CLS, H5E_IO, H5E_FILEEXISTS, "file exists but CREAT and EXCL were specified", NULL)
-    } else if (flags & H5F_ACC_RDWR) {
-        if (flags & H5F_ACC_TRUNC)
-            f = fopen(name, "wb+");
-        else
-            f = fopen(name, "rb+");
+    } else if(flags & H5F_ACC_RDWR) {
+        if(flags & H5F_ACC_TRUNC)
+            f = freopen(name, "wb+", f);
         write_access = 1;     /* Note the write access */
-    } else {
-        f = fopen(name, "rb");
-    }
-    if (!f)
+    } /* end if */
+    /* Note there is no need to reopen if neither TRUNC nor EXCL are specified,
+     * as the tentative open will work */
+
+    if(!f)
         H5Epush_ret(func, H5E_ERR_CLS, H5E_IO, H5E_CANTOPENFILE, "fopen failed", NULL)
 
     /* Build the return value */
@@ -403,32 +397,43 @@ H5FD_stdio_open( const char *name, unsigned flags, hid_t fapl_id,
     }
 
     /* Get the file descriptor (needed for truncate and some Windows information) */
+#ifdef H5_HAVE_WIN32_API
+    file->fd = _fileno(file->fp);
+#else /* H5_HAVE_WIN32_API */
     file->fd = fileno(file->fp);
-    if(file->fd < 0)
+#endif /* H5_HAVE_WIN32_API */
+    if(file->fd < 0) {
+        free(file);
+        fclose(f);
         H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_CANTOPENFILE, "unable to get file descriptor", NULL);
+    } /* end if */
 
 
 #ifdef H5_HAVE_WIN32_API
     file->hFile = (HANDLE)_get_osfhandle(file->fd);
-    if(INVALID_HANDLE_VALUE == file->hFile)
+    if(INVALID_HANDLE_VALUE == file->hFile) {
+        free(file);
+        fclose(f);
         H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_CANTOPENFILE, "unable to get Windows file handle", NULL);
+    } /* end if */
 
-    if(!GetFileInformationByHandle((HANDLE)file->hFile, &fileinfo))
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_CANTOPENFILE, "unable to get Windows file desinformationcriptor", NULL);
+    if(!GetFileInformationByHandle((HANDLE)file->hFile, &fileinfo)) {
+        free(file);
+        fclose(f);
+        H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_CANTOPENFILE, "unable to get Windows file descriptor information", NULL);
+    } /* end if */
 
     file->nFileIndexHigh = fileinfo.nFileIndexHigh;
     file->nFileIndexLow = fileinfo.nFileIndexLow;
     file->dwVolumeSerialNumber = fileinfo.dwVolumeSerialNumber;
 #else /* H5_HAVE_WIN32_API */
-    fstat(file->fd, &sb);
+    if(fstat(file->fd, &sb) < 0) {
+        free(file);
+        fclose(f);
+        H5Epush_ret(func, H5E_ERR_CLS, H5E_FILE, H5E_BADFILE, "unable to fstat file", NULL)
+    } /* end if */
     file->device = sb.st_dev;
-#ifdef H5_VMS
-    file->inode[0] = sb.st_ino[0];
-    file->inode[1] = sb.st_ino[1];
-    file->inode[2] = sb.st_ino[2];
-#else /* H5_VMS */
     file->inode = sb.st_ino;
-#endif /* H5_VMS */
 #endif /* H5_HAVE_WIN32_API */
 
     return (H5FD_t*)file;
@@ -514,13 +519,8 @@ H5FD_stdio_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
     if(memcmp(&(f1->device),&(f2->device),sizeof(dev_t)) < 0) return -1;
     if(memcmp(&(f1->device),&(f2->device),sizeof(dev_t)) > 0) return 1;
 #endif /* H5_DEV_T_IS_SCALAR */
-#ifdef H5_VMS
-    if(memcmp(&(f1->inode), &(f2->inode), 3 * sizeof(ino_t)) < 0) return -1;
-    if(memcmp(&(f1->inode), &(f2->inode), 3 * sizeof(ino_t)) > 0) return 1;
-#else /* H5_VMS */
     if(f1->inode < f2->inode) return -1;
     if(f1->inode > f2->inode) return 1;
-#endif /* H5_VMS */
 #endif /* H5_HAVE_WIN32_API */
 
     return 0;
@@ -580,7 +580,7 @@ H5FD_stdio_query(const H5FD_t *_f, unsigned long *flags /* out */)
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxpl_id, hsize_t size)
+H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, hid_t /*H5_ATTR_UNUSED*/ dxpl_id, hsize_t size)
 {
     H5FD_stdio_t    *file = (H5FD_stdio_t*)_file;
     haddr_t         addr;
@@ -625,7 +625,7 @@ H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxp
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type)
+H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type)
 {
     const H5FD_stdio_t *file = (const H5FD_stdio_t *)_file;
 
@@ -656,7 +656,7 @@ H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, haddr_t addr)
+H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t /*H5_ATTR_UNUSED*/ type, haddr_t addr)
 {
     H5FD_stdio_t  *file = (H5FD_stdio_t*)_file;
 
@@ -771,8 +771,6 @@ H5FD_stdio_read(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr, siz
         H5Epush_ret (func, H5E_ERR_CLS, H5E_IO, H5E_OVERFLOW, "file address overflowed", -1)
     if (REGION_OVERFLOW(addr, size))
         H5Epush_ret (func, H5E_ERR_CLS, H5E_IO, H5E_OVERFLOW, "file address overflowed", -1)
-    if((addr + size) > file->eoa)
-        H5Epush_ret(func, H5E_ERR_CLS, H5E_IO, H5E_OVERFLOW, "file address overflowed", -1)
 
     /* Check easy cases */
     if (0 == size)
@@ -878,8 +876,6 @@ H5FD_stdio_write(H5FD_t *_file, H5FD_mem_t type, hid_t dxpl_id, haddr_t addr,
         H5Epush_ret (func, H5E_ERR_CLS, H5E_IO, H5E_OVERFLOW, "file address overflowed", -1)
     if (REGION_OVERFLOW(addr, size))
         H5Epush_ret (func, H5E_ERR_CLS, H5E_IO, H5E_OVERFLOW, "file address overflowed", -1)
-    if (addr+size > file->eoa)
-        H5Epush_ret (func, H5E_ERR_CLS, H5E_IO, H5E_OVERFLOW, "file address overflowed", -1)
 
     /* Seek to the correct file position. */
     if ((file->op != H5FD_STDIO_OP_WRITE && file->op != H5FD_STDIO_OP_SEEK) ||
