@@ -5,12 +5,10 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at the  *
- * root level of an installed copy of the electronic HDF5 document set and   *
- * is linked from the top-level documents page.  It can also be found at     *
- * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /***********************************************************
@@ -493,13 +491,19 @@ test_reference_region(void)
     hsize_t	high[SPACE2_RANK];	/* Selection bounds */
     hdset_reg_ref_t      *wbuf,		/* buffer to write to disk */
                *rbuf;       /* buffer read from disk */
-    hdset_reg_ref_t  nvrbuf[3]={{0},{101},{1000000000}}; /* buffer with non-valid refs */
+    hdset_reg_ref_t  nvrbuf[3]={{0},{101},{255}}; /* buffer with non-valid refs */
     uint8_t    *dwbuf,      /* Buffer for writing numeric data to disk */
                *drbuf;      /* Buffer for reading numeric data from disk */
     uint8_t    *tu8;        /* Temporary pointer to uint8 data */
     H5O_type_t  obj_type;       /* Type of object */
     int        i, j;           /* counting variables */
     herr_t	ret;		/* Generic return value		*/
+    haddr_t     addr = HADDR_UNDEF; /* test for undefined reference */
+    hid_t dset_NA;   /* Dataset id for undefined reference */
+    hid_t space_NA; /* Dataspace id for undefined reference */
+    hsize_t             dims_NA[1] = {1};  /* Dims array for undefined reference */
+    hdset_reg_ref_t     wdata_NA[1],       /* Write buffer */
+                        rdata_NA[1];       /* Read buffer */
 
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Dataset Region Reference Functions\n"));
@@ -586,6 +590,31 @@ test_reference_region(void)
     ret = H5Dwrite(dset1, H5T_STD_REF_DSETREG, H5S_ALL, H5S_ALL, H5P_DEFAULT, wbuf);
     CHECK(ret, FAIL, "H5Dwrite");
 
+    /*
+     * Store a dataset region reference which will not get written to disk
+     */
+
+    /* Create reference to an element in dset1 */
+    ret = H5Sselect_elements(sid2, H5S_SELECT_SET, (size_t)1, (const hsize_t *)coord1);
+    CHECK(ret, FAIL, "H5Sselect_elements");
+    ret = H5Rcreate(&wdata_NA[0], fid1, "/Dataset1", H5R_DATASET_REGION, sid2);
+    CHECK(ret, FAIL, "H5Rcreate");
+
+    /* Create the dataspace of the region references */
+    space_NA = H5Screate_simple(1, dims_NA, NULL);
+    CHECK(space_NA, FAIL, "H5Screate_simple");
+
+    /* Create the dataset and write the region references to it */
+    dset_NA = H5Dcreate2(fid1, "DS_NA", H5T_STD_REF_DSETREG, space_NA, H5P_DEFAULT,
+                H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(dset_NA, FAIL, "H5Dcreate");
+
+    /* Close and release resources for undefined region reference tests */
+    ret = H5Dclose(dset_NA);
+    CHECK(ret, FAIL, "H5Dclose");
+    ret = H5Sclose(space_NA); 
+    CHECK(ret, FAIL, "H5Sclose");
+
     /* Close disk dataspace */
     ret = H5Sclose(sid1);
     CHECK(ret, FAIL, "H5Sclose");
@@ -606,6 +635,41 @@ test_reference_region(void)
     fid1 = H5Fopen(FILE2, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid1, FAIL, "H5Fopen");
 
+    /* 
+     * Start the test of an undefined reference 
+     */
+    
+    /* Open the dataset of the undefined references */
+    dset_NA = H5Dopen2(fid1, "DS_NA", H5P_DEFAULT);
+    CHECK(dset_NA, FAIL, "H5Dopen2");
+
+    /* Read the data */
+    ret = H5Dread(dset_NA, H5T_STD_REF_DSETREG, H5S_ALL, H5S_ALL, H5P_DEFAULT, rdata_NA);
+    CHECK(ret, FAIL, "H5Dread");
+    
+    /*
+     * Dereference an undefined reference (should fail)
+     */
+    H5E_BEGIN_TRY {
+      dset2 = H5Rdereference(dset_NA, H5R_DATASET_REGION, &rdata_NA[0]);
+    } H5E_END_TRY;                                  
+    VERIFY(dset2, FAIL, "H5Rdereference"); 
+
+    /* Close and release resources. */
+    ret = H5Dclose(dset_NA);
+    CHECK(ret, FAIL, "H5Dclose");
+
+    /* This close should fail since H5Rdereference never created 
+     * the id of the referenced object. */
+    H5E_BEGIN_TRY {
+      ret = H5Dclose(dset2);
+    } H5E_END_TRY;                                  
+    VERIFY(ret, FAIL, "H5Dclose"); 
+
+    /* 
+     * End the test of an undefined reference 
+     */
+
     /* Open the dataset */
     dset1 = H5Dopen2(fid1, "/Dataset1", H5P_DEFAULT);
     CHECK(dset1, FAIL, "H5Dopen2");
@@ -614,6 +678,10 @@ test_reference_region(void)
     ret = H5Dread(dset1, H5T_STD_REF_DSETREG, H5S_ALL, H5S_ALL, H5P_DEFAULT, rbuf);
     CHECK(ret, FAIL, "H5Dread");
 
+    /* Try to read an unaddressed dataset */
+    dset2 = H5Rdereference(dset1, H5R_DATASET_REGION, &addr);
+    VERIFY(dset2, FAIL, "H5Rdereference haddr_undef");
+
     /* Try to open objects */
     dset2 = H5Rdereference(dset1, H5R_DATASET_REGION, &rbuf[0]);
     CHECK(dset2, FAIL, "H5Rdereference");
@@ -646,7 +714,7 @@ test_reference_region(void)
     VERIFY(ret, 36, "H5Sget_select_npoints");
     ret = (int)H5Sget_select_hyper_nblocks(sid2);
     VERIFY(ret, 1, "H5Sget_select_hyper_nblocks");
-    coords = HDmalloc(ret * SPACE2_RANK * sizeof(hsize_t) * 2); /* allocate space for the hyperslab blocks */
+    coords = (hsize_t *)HDmalloc(ret * SPACE2_RANK * sizeof(hsize_t) * 2); /* allocate space for the hyperslab blocks */
     ret = H5Sget_select_hyper_blocklist(sid2, (hsize_t)0, (hsize_t)ret, coords);
     CHECK(ret, FAIL, "H5Sget_select_hyper_blocklist");
     VERIFY(coords[0], 2, "Hyperslab Coordinates");
@@ -674,7 +742,7 @@ test_reference_region(void)
     VERIFY(ret, 10, "H5Sget_select_npoints");
     ret = (int)H5Sget_select_elem_npoints(sid2);
     VERIFY(ret, 10, "H5Sget_select_elem_npoints");
-    coords = HDmalloc(ret * SPACE2_RANK * sizeof(hsize_t)); /* allocate space for the element points */
+    coords = (hsize_t *)HDmalloc(ret * SPACE2_RANK * sizeof(hsize_t)); /* allocate space for the element points */
     ret = H5Sget_select_elem_pointlist(sid2, (hsize_t)0, (hsize_t)ret, coords);
     CHECK(ret, FAIL, "H5Sget_select_elem_pointlist");
     VERIFY(coords[0], coord1[0][0], "Element Coordinates");
@@ -1031,6 +1099,7 @@ test_reference_obj_deleted(void)
     hid_t		sid1;       /* Dataspace ID			*/
     hobj_ref_t  oref;       /* Object Reference to test */
     H5O_type_t          obj_type;       /* Object type */
+    haddr_t addr = HADDR_UNDEF; /* test for undefined reference */                
     herr_t		ret;		/* Generic return value		*/
 
     /* Create file */
@@ -1088,6 +1157,10 @@ test_reference_obj_deleted(void)
     dataset = H5Dopen2(fid1, "/Dataset2", H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Dopen2");
 
+    /* Open undefined reference */
+    dset2 = H5Rdereference(dataset, H5R_OBJECT, &addr);
+    VERIFY(dset2, FAIL, "H5Rdereference");
+
     /* Read selection from disk */
     HDmemset(&oref, 0, sizeof(hobj_ref_t));
     ret = H5Dread(dataset, H5T_STD_REF_OBJ, H5S_ALL, H5S_ALL, H5P_DEFAULT, &oref);
@@ -1118,7 +1191,7 @@ test_reference_obj_deleted(void)
 **
 ****************************************************************/
 static herr_t
-test_deref_iter_op(hid_t UNUSED group, const char *name, const H5L_info_t UNUSED *info,
+test_deref_iter_op(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info_t H5_ATTR_UNUSED *info,
     void *op_data)
 {
     int *count = (int *)op_data;        /* Pointer to name counter */
