@@ -5,12 +5,10 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at the  *
- * root level of an installed copy of the electronic HDF5 document set and   *
- * is linked from the top-level documents page.  It can also be found at     *
- * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /* Unicode test */
@@ -39,8 +37,8 @@
 
 #define RANK 1
 #define COMP_INT_VAL 7
-#define COMP_FLOAT_VAL -42.0
-#define COMP_DOUBLE_VAL 42.0
+#define COMP_FLOAT_VAL -42.0F
+#define COMP_DOUBLE_VAL 42.0F
 
 /* Test function prototypes */
 void test_fl_string(hid_t fid, const char *string);
@@ -119,7 +117,7 @@ void test_fl_string(hid_t fid, const char *string)
  * Borrows heavily from dtypes.c, but is more complicated because
  * the string is randomly generated.
  */
-void test_strpad(hid_t UNUSED fid, const char *string)
+void test_strpad(hid_t H5_ATTR_UNUSED fid, const char *string)
 {
     /* buf is used to hold the data that H5Tconvert operates on. */
     char     buf[LONG_BUF_SIZE];
@@ -650,7 +648,7 @@ void test_compound(hid_t fid, const char * string)
  * test_enum
  * Test that enumerated datatypes can have UTF-8 member names.
  */
-void test_enum(hid_t UNUSED fid, const char * string)
+void test_enum(hid_t H5_ATTR_UNUSED fid, const char * string)
 {
   /* Define an enumerated type */
   typedef enum {
@@ -699,7 +697,7 @@ void test_enum(hid_t UNUSED fid, const char * string)
  * test_opaque
  * Test comments on opaque datatypes
  */
-void test_opaque(hid_t UNUSED fid, const char * string)
+void test_opaque(hid_t H5_ATTR_UNUSED fid, const char * string)
 {
   hid_t type_id;
   char * read_buf;
